pub struct DiskUsageItem {
pub fs_type: FileSystemType,
pub path: String,
pub size_in_bytes: usize,
pub children: Option<Vec<DiskUsageItem>>,
}Expand description
Fields
fs_type: FileSystemTypeType of the entry.
path: StringRelative path in the DittoRoot.
size_in_bytes: usizeSize of the entry in bytes. For directories, this includes the size of all children.
children: Option<Vec<DiskUsageItem>>If the entry is a directory, it contains child items.