pub struct DiskUsageObserver<F: ?Sized + DiskUsageCallback> { /* private fields */ }Expand description
Handle returned by DiskUsage::observe.
Keep this observer in scope as long as you want to receive updates on disk usage changes. Dropping the observer will stop the observation.