Differ

Struct Differ 

pub struct Differ { /* private fields */ }
Calculates diffs between arrays of QueryResultItems.

Use a Differ with a StoreObserver to get the diff between subsequent query results delivered by the store observer.

Implementations

Source

impl Differ

pub fn new() -> Self

Create a new Differ instance.

pub fn diff(&self, items: impl IntoIterator<Item = QueryResultItem>) -> Diff

Calculate the diff of the provided items against the last set of items that were passed to this differ.

The returned Diff identifies changes from the old array of items to the new array of items using indices into both arrays.

Initially, the differ has no items, so the first call to this method will always return a diff showing all items as insertions.

The identity of items is determined by their _id field.

  • items The query result items to compare against the last array of items.