Query

Struct Query 

pub struct Query<Args> { /* private fields */ }
A DQL query string with its arguments

Most APIs in the Ditto SDK don’t take a Query directly, but instead take a generic parameter that implements IntoQuery, a trait implemented by types that can be turned into a Query.

Common examples are:

  • String (and string-like types)
  • (String, Args) where Args is anything that implements Serialize
let select_query = "SELECT * FROM cars".into_query();

let insert_query = (
    "INSERT INTO cars DOCUMENTS (:doc)",
    json!({"doc": {"foo": "bar"}}),
).into_query();

The Args type

This type is generic over its arguments, with the requirement that the arguments must:

If the arguments are mutated using interior mutability, the result is not specified and may cause logic errors. Note that this is not undefined behaviour, since any errors will be confined to this instance of Query.

When no arguments are provided, the Args type defaults to ()