pub trait DittoRoot: Send + Sync {
// Required methods
fn root_path(&self) -> &Path;
fn exists(&self) -> bool;
fn is_valid(&self) -> Result<(), DittoError>;
// Provided methods
fn root_dir_to_c_str(&self) -> Result<Box, DittoError> { ... }
fn root_path_as_str(&self) -> Result<&str, DittoError> { ... }
}Expand description
Interface provided by the Filesystem directory into which Ditto will store its local data
Required Methods
Sourcefn is_valid(&self) -> Result<(), DittoError>
fn is_valid(&self) -> Result<(), DittoError>
Return true if the provided Root path is a valid path
Provided Methods
Sourcefn root_dir_to_c_str(&self) -> Result<Box, DittoError>
fn root_dir_to_c_str(&self) -> Result<Box, DittoError>
Emits the Ditto root directory path as a null-terminated UTF-8 C-string
Sourcefn root_path_as_str(&self) -> Result<&str, DittoError>
fn root_path_as_str(&self) -> Result<&str, DittoError>
Return the Root path as a &str