AuthenticationClientFeedback

Struct AuthenticationClientFeedback 

pub struct AuthenticationClientFeedback {
    pub feedback: Option<Value>,
}
Feedback provided by an authentication provider.

This feedback may include arbitrary JSON, and may be used to give details about an authentication success or explain why it was rejected.

Fields

feedback: Option<Value>

If present, this object contains feedback from the authentication provider.