#[non_exhaustive]pub struct Connection {
pub id: String,
pub peer1: String,
pub peer2: String,
pub connection_type: ConnectionType,
}Expand description
Represents a connection between two peers in a Ditto mesh network.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringAn string ID in the form "from<->to:connection_type". These ids
are stable: the lower site Id will always be placed first.
Example
“1<->2:Bluetooth”
peer1: StringThe peer key of the peer at one end of the connection.
The assignment to peer1 and peer2 is deterministic and stable for
any two peers.
peer2: StringThe peer key of the peer at the other end of the connection.
The assignment to peer1 and peer2 is deterministic and stable for
any two peers.
connection_type: ConnectionTypeThe type of connection. One Connection will exist
for each connection type that might be active.