WriteStrategy

Enum WriteStrategy 

#[non_exhaustive]
pub enum WriteStrategy { Merge, InsertIfAbsent, InsertDefaultIfAbsent, }
Specify the write strategy when inserting documents.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Merge

An existing document will be merged with the document being inserted, if there is a pre-existing document.



InsertIfAbsent

Insert the document only if there is not already a document with the same Id in the store. If there is already a document in the store with the same Id then this will be a no-op.



InsertDefaultIfAbsent

Insert the document, with its contents treated as default data, only if there is not already a document with the same Id in the store. If there is already a document in the store with the same Id then this will be a no-op. Use this strategy if you want to insert default data for a given document Id, which you want to treat as common initial data amongst all peers and that you expect to be mutated or overwritten in due course.