LiveQueryEvent

Enum LiveQueryEvent 

pub enum LiveQueryEvent {
    Initial,
    Update {
        old_documents: Vec<BoxedDocument>,
        insertions: Box<[usize]>,
        deletions: Box<[usize]>,
        updates: Box<[usize]>,
        moves: Vec<LiveQueryMove>,
    },
}
👎Deprecated: Use ditto.store().execute_v2(...) or ditto.store().register_observer_v2(...) instead
Use pending_op.observe_local(...) to receive LiveQueryEvents describing document changes.

Describes the different types of event that you can receive when dealing with live queries.

Variants



Initial

👎Deprecated: Use ditto.store().execute_v2(...) or ditto.store().register_observer_v2(...) instead

The first event that will be delivered and it will only be delivered once.



Update

👎Deprecated: Use ditto.store().execute_v2(...) or ditto.store().register_observer_v2(...) instead

This event will be delivered each time the results of the provided query change. It contains information about the set of documents that previously matched the query before the update, along with information about what documents have been inserted, deleted, updated, or moved, as part of the set of matching documents.

Fields

old_documents: Vec<BoxedDocument>
👎Deprecated: Use ditto.store().execute_v2(...) or ditto.store().register_observer_v2(...) instead
insertions: Box<[usize]>
👎Deprecated: Use ditto.store().execute_v2(...) or ditto.store().register_observer_v2(...) instead
deletions: Box<[usize]>
👎Deprecated: Use ditto.store().execute_v2(...) or ditto.store().register_observer_v2(...) instead
updates: Box<[usize]>
👎Deprecated: Use ditto.store().execute_v2(...) or ditto.store().register_observer_v2(...) instead
moves: Vec<LiveQueryMove>
👎Deprecated: Use ditto.store().execute_v2(...) or ditto.store().register_observer_v2(...) instead

Implementations

Source

impl LiveQueryEvent

pub fn hash(&self, docs: &[BoxedDocument]) -> Result<u64, DittoError>

👎Deprecated: Use ditto.store().execute_v2(...) or ditto.store().register_observer_v2(...) instead

Return an hash of a document

pub fn hash_mnemonic( &self, docs: &[BoxedDocument], ) -> Result<String, DittoError>

👎Deprecated: Use ditto.store().execute_v2(...) or ditto.store().register_observer_v2(...) instead

Return the hash the Documents mnemonic.