pub struct UpdateResult {
pub op: UpdateOp,
pub doc_id: String,
pub path: String,
pub value: Box<dyn Debug>,
}👎Deprecated since 4.14.4: Will be removed in SDK 5.0. Use DQL queries instead
Describes the result of an update operation performed on a DittoMutDocument.
- set: Describes the
setupdate that was performed. - removed: Describes the
removeupdate that was performed. - incremented: Describes the
incrementupdate that was performed.
Fields
op: UpdateOp👎Deprecated since 4.14.4: Will be removed in SDK 5.0. Use DQL queries instead
The type of update operation performed.
doc_id: String👎Deprecated since 4.14.4: Will be removed in SDK 5.0. Use DQL queries instead
The ID of the document updated.
path: String👎Deprecated since 4.14.4: Will be removed in SDK 5.0. Use DQL queries instead
The path to the field in the document that was updated.
value: Box<dyn Debug>👎Deprecated since 4.14.4: Will be removed in SDK 5.0. Use DQL queries instead
A printable representation of the updated value.