pub struct WriteTransactionResult {
pub collection_name: Box,
pub doc_id: DocumentId,
pub kind: DocChangeKind,
}👎Deprecated since 4.14.4: Will be removed in SDK 5.0. Use DQL queries instead
Returned from .with_batched_write(...) and describes the operations performed in the batch.
Provides information about the result of an operation on a document that was part of a write transaction.
Fields
collection_name: Box👎Deprecated since 4.14.4: Will be removed in SDK 5.0. Use DQL queries instead
The name of the collection that the operation took place in.
doc_id: DocumentId👎Deprecated since 4.14.4: Will be removed in SDK 5.0. Use DQL queries instead
The Id of the document that the write transaction result applies to.
kind: DocChangeKind👎Deprecated since 4.14.4: Will be removed in SDK 5.0. Use DQL queries instead
The type of write transaction result.